<?php
/**
 * Deprecated functions that should be avoided in favor of newer functions
 * Also handles removed functions to avoid errors
 *
 * @package Hybrid
 * @subpackage Functions
 */

/**
 * Function for handling the old content div
 * This is for an ongoing transition to move the content div inside of template files
 * By taking the content div out of header.php, we have greater layout flexibility
 * Users should use the .content or .hfeed class to style their content area until version 1.0
 *
 * @todo Phase out the use of <div id="content">
 *
 * @since 0.5
 * @deprecated 0.5
 * @internal Yes, we're both creating and deprecating this in the same version.
 */
function hybrid_content_wrapper( $div = '' ) {
	if ( $div == 'open' )
		echo '<div id="content"> <!-- Deprecated. Use the .content or .hfeed class for styling instead of #content. -->';
	elseif ( $div == 'close' )
		echo '</div> <!-- Deprecated. Use the .content or .hfeed class for styling instead of #content. -->';
}

/**
 * Sets alternating classes for posts
 * Gives class of odd/even and post-#
 *
 * @internal This function should remain until version 1.0
 *
 * @since 0.2
 * @deprecated 0.5 for better naming conventions
 */
function hybrid_post_class( $deprecated = '' ) {
	hybrid_entry_class( $deprecated );
}

// Register widget sections
// @deprecated 0.5
hybrid_widget_init(hybrid_primary_inserts());
hybrid_widget_init(hybrid_secondary_inserts());
hybrid_widget_init(hybrid_subsidiary_inserts());
hybrid_widget_init(hybrid_utility_inserts());

/**
 * Add widget inserts to array
 * Filterable to add/remove inserts in child themes
 * Filter hybrid_primary_args adds additional inserts
 * Filter hybrid_primary_inserts overwrites all inserts
 *
 * Use the register_sidebar() function to create custom widget areas
 *
 * @since 0.1
 * @deprecated 0.5
 * @return array
 */
function hybrid_primary_inserts() {
	$args = false;
	$args = apply_filters('hybrid_primary_args', $args);
	return apply_filters('hybrid_primary_inserts', $args);
}

/**
 * Add widget inserts to array
 * Filterable to add/remove inserts in child themes
 * Filter hybrid_secondary_args Adds additional inserts
 * Filter hybrid_secondary_inserts Overwrites all inserts
 *
 * Use the register_sidebar() function to create custom widget areas
 *
 * @since 0.2
 * @deprecated 0.5
 * @return array
 */
function hybrid_secondary_inserts() {
	$args = false;
	$args = apply_filters('hybrid_secondary_args', $args);
	return apply_filters('hybrid_secondary_inserts', $args);
}

/**
 * Function for additional widget inserts
 * These inserts should not fall under the Primary/Secondary domain
 * Widget inserts that go here should belong to the larger whole of Subsidiary
 * Else, use the utility inserts
 * Filter overwritten (bug) until 0.3.2
 * Filter hybrid_subsidiary_args Adds additional inserts
 * Filter hybrid_subsidiary_inserts Overwrites all inserts
 *
 * Use the register_sidebar() function to create custom widget areas
 *
 * @since 0.3
 * @deprecated 0.5
 * @return array
 */
function hybrid_subsidiary_inserts() {
	$args = false;
	$args = apply_filters('hybrid_subsidiary_args', $args);
	return apply_filters('hybrid_subsidiary_inserts', $args);
}

/**
 * Function for adding additional widget inserts
 * Individual widget inserts should go here
 * Add here because they don't belong to a larger whole
 * Filter hybrid_utility_args adds additional utility sections
 * Filter hybrid_utility_inserts overwrites all utility sections
 *
 * Use the register_sidebar() function to create custom widget areas
 *
 * @since 0.3.2
 * @deprecated 0.5
 * @return array
 */
function hybrid_utility_inserts() {
	$args = false;
	$args = apply_filters('hybrid_utility_args', $args);
	return apply_filters('hybrid_utility_inserts', $args);
}

/**
 * Loop through an array of widget area names/ids
 * Creates individual widget displays
 * By calling this function, we can easily create many widgets
 * Without having to rewrite the same code over and over
 * Standardizing each set of widgets with specific elements that can easily be styled
 *
 * @since 0.2.1
 * @deprecated 0.5
 * @param array $insert_id widget sections to register
 */
function hybrid_widget_init( $insert_id = false ) {
	if ( $insert_id && is_array( $insert_id) ) :
		foreach ( $insert_id as $insert ) :
			$the_id = strtolower( $insert );
			$the_id = preg_replace( '/[^a-z0-9]/', '', $the_id );
			register_sidebar( array( 'name' => $insert, 'id' => $the_id, 'before_widget' => '<div id="%1$s" class="widget %2$s widget-%2$s"><div class="widget-inside">', 'after_widget' => '</div></div>', 'before_title' => '<h3 class="widget-title">', 'after_title' => '</h3>' ) );
		endforeach;
	endif;
}

/**
 * Runs through a list of primary inserts according to page
 * Let users filter through the child theme if necessary
 *
 * @since 0.1
 * @deprecated 0.5
 * @return string
 */
function hybrid_primary_var() {
	if(!is_page_template('no-widgets.php'))
		$hybrid_insert_id = __('Primary', 'hybrid');
	return apply_filters('hybrid_primary_var', $hybrid_insert_id);
}

/**
 * Runs through a list of secondary inserts according to page
 * Let users filter through the child theme if necessary
 *
 * @since 0.1
 * @deprecated 0.5
 * @return string
 */
function hybrid_secondary_var() {
	if(!is_page_template('no-widgets.php'))
		$hybrid_insert_id = __('Secondary', 'hybrid');
	return apply_filters('hybrid_secondary_var', $hybrid_insert_id);
}

/**
 * Runs through a list of subsidiary inserts according to page
 * Let users filter through the child theme if necessary
 *
 * @since 0.3.1
 * @deprecated 0.5
 * @return string
 */
function hybrid_subsidiary_var() {
	if(!is_page_template('no-widgets.php'))
		$hybrid_insert_id = __('Subsidiary', 'hybrid');
	return apply_filters('hybrid_subsidiary_var', $hybrid_insert_id);
}

/*
* If users need to add this functionality back in,
* they should add_action in their child theme's functions.php
*/
// add_action('hybrid_after_container', 'hybrid_insert');

/**
 * Returns an array of available categories
 * Returns categories by name
 * Most calls should use hybrid_all_cat_slugs() if possible when using query_posts()
 * Addition of 'none' category for use on the theme settings page
 *
 * @since 0.2
 * @deprecated 0.5
 * @return array
 */
function hybrid_all_cats() {
	$all_cats = get_all_category_ids();
	foreach($all_cats as $key => $value) :
		$all_cats[$key] = get_cat_name($all_cats[$key]);
		$all_cats[$key] = str_replace("&#038;", "&", $all_cats[$key]);
		$all_cats[$key] = str_replace("&amp;","&", $all_cats[$key]);
	endforeach;
	$all_cats['none'] = false;
	return $all_cats;
}

/**
 * Returns an array of available category slugs
 * Better for use when eventually using query_posts() by category_name
 * query_posts() doesn't like non-matching names/slugs
 * Addition of 'none' category for use on the theme settings page
 *
 * @since 0.2
 * @deprecated 0.5
 * @return array
 */
function hybrid_all_cat_slugs() {
	$cats = get_categories("hierarchical=0");
	foreach($cats as $key) :
		$all_cats[] = $key->category_nicename;
	endforeach;
	$all_cats['none'] = false;
	return $all_cats;
}

/**
 * Returns an array of the available tags (slugs)
 * Addition of 'none' tag for use on the theme settings page
 *
 * @since 0.2
 * @deprecated 0.5
 * @internal renamed this function in 0.2.3
 * @return array
 */
function hybrid_all_tag_slugs() {
	$all_tags = wp_tag_cloud('number=0&format=array');
	if($all_tags) :
		foreach($all_tags as $key => $value) :
			$value = strip_tags(stripslashes($value));
			$value = strtolower($value);
			$value = str_replace(array("&nbsp;", " "), "-", $value);
			$all_tags[$key] = $value;
		endforeach;
	endif;
	$all_tags['none'] = false;
	return $all_tags;
}

/**
 * Checks the mime type and attachment extension
 * Calls a function, if needed, to handle the output
 *
 * Now just loads the hybrid_attachment() function
 *
 * @since 0.2.2
 * @deprecated 0.5 Uses hybrid_attachment() instead
 * @param string $mime attachment mime type
 * @param string $file attachment file URL
 */
function hybrid_handle_attachment( $deprecated = '', $deprecated_2 = '' ) {
	hybrid_attachment();
}

/**
 * Gets rid of quotes and slashes
 * Runs text through stripslashes() and htmlentities()
 * Simple function to cut back on use in code
 *
 * Now just returns the text input
 * Should use wp_specialchars() instead
 *
 * @since 0.3.1
 * @deprecated 0.5
 */
function hybrid_text_filter( $text = '' ) {
	return $text;
}

/**
 * Alllowed comment form tags
 * Not shown by default
 *
 * Now just returns the WP allowed_tags() function
 * Users should create their own function and add it to comment_form hook
 *
 * @since 0.2.2
 * @deprecated 0.5
 * @return string
 */
function hybrid_allowed_tags() {
	echo '<p class="allowed-tags">';
	echo '<strong>' . __('You can use these <acronym title="Extensible Hypertext Markup Language">XHTML</acronym> tags&#58;','hybrid') . '</strong> ';
	echo allowed_tags();
	echo '</p>';
}

/**
 * Make typography easier
 * It shouldn't be so hard, so we call a few functions and filter the content
 *
 * @deprecated 0.5
 * Individual functions should be called
 * hybrid_widow() was becoming a pain with some plugins
 *
 * @since 0.3.1
 */
function hybrid_typography($text) {
	return $text;
}

/**
 * This function no longer checks for capabilities
 * It will still return true if the user is logged in
 *
 * @since 0.2.3
 * @deprecated 0.5 No longer in use by the theme
 * @param array $deprecated
 * @return bool
 */
function hybrid_capability_check( $deprecated = '' ) {
	if ( is_user_logged_in() )
		return true;
	else
		return false;
}

/**
 * Checks if the template exists and returns appropriate link
 * Useful for log in, publish, and registration templates and functions
 *
 * This function now just returns the URL based on WP's standard
 *
 * @since 0.3
 * @deprecated 0.5 Kind of a crude method (need to use a filter)
 * @param string $template name of page template
 * @return string|bool
 */
function hybrid_template_in_use( $template = '' ) {
	$link = false;
	if ( $template == 'log-in.php' )
		$link = wp_login_url( get_permalink() );
	elseif ( $template == 'register.php' )
		$link = get_option( 'siteurl' ) . '/wp-register.php';
	return $link;
}

/**
 * Defines the classes for widgets
 * Currently trying to add alt classes, but can't get it to work
 *
 * @since 0.2.2
 * @deprecated 0.5 Using a filter would work better
 * @return string
 */
function hybrid_widget_class() {
// Widget class
	$class = array();
	$class[] = 'widget';
	$class[] = '%2$s';
	$class[] = 'widget-%2$s';
// Join the classes in an array
	$class = join( ' ', $class );
	return apply_filters( 'hybrid_widget_class', $class );
}

/**
 * Pulls an image for the particular mime type
 * Currently, just passes variables to hybrid_attachment_icon
 * Need to update and work with wp_mime_type_icon()
 *
 * @since 0.2.3
 * @deprecated 0.5 Uses wp_mime_type_icon() instead
 * @param string $mime attachment mime type
 * @param string $file attachment file URL
 */
function hybrid_mime_type_icon( $deprecated = '', $deprecated_2 = '' ) {
	echo '<img class="attachment-icon" src="' . wp_mime_type_icon() . '" alt="' . get_post_mime_type() . '" />';
}

/**
 * Displays icons for attachments
 *
 * @since 0.2.2
 * @deprecated 0.5 Uses wp_mime_type_icon() instead
 * @param string $mime attachment mime type
 * @param string $file attachment file URL
 */
function hybrid_attachment_icon( $deprecated = '', $deprecated_2 = '' ) {
	echo '<img class="attachment-icon" src="' . wp_mime_type_icon() . '" alt="' . get_post_mime_type() . '" />';
}

/*
	=== Removed Functions ===
*/

/**
 * Returns an array of the available tags (slugs)
 *
 * @since 0.2
 * @deprecated 0.2.3
 * @internal function removed in 0.5
 * @return array
 */
function hybrid_all_tags() {
	hybrid_function_removed( 'hybrid_all_tags' );
}

/**
 * Calls up several theme functions to get meta info
 *
 * @since 0.1
 * @internal function removed in 0.4
 */
function hybrid_theme_meta() {
	hybrid_function_removed( 'hybrid_theme_meta' );
}

/**
 * Generates other relevant meta info
 * Adds template meta with theme version
 *
 * @since 0.2.3
 * @internal function removed in 0.4
 */
function hybrid_meta_other() {
	hybrid_function_removed( 'hybrid_meta_other' );
}

/**
 * Function for loading a video
 *
 * @since 0.2
 * @internal function removed in 0.3.1
 */
function load_the_video() {
	hybrid_function_removed( 'load_the_video' );
}

/**
 * Function for getting insert
 * Replacement for get_sidebar()
 *
 * @since 0.1
 * @internal function removed in 0.2.2
 */
function hybrid_get_insert() {
	hybrid_function_removed( 'hybrid_get_insert' );
}

/**
 * Function to load SimplePie correctly
 *
 * @since 0.2.3
 * @deprecated 0.3.3
 * @internal function removed in 0.4
 * @link http://simplepie.org
 */
function hybrid_load_SimplePie() {
	hybrid_function_removed( 'hybrid_load_SimplePie' );
}

/**
 * Uses SimplePie to display feeds
 * Must load SimplePie before using
 * Load SimplePie with hybrid_load_SimplePie()
 *
 * @since 0.2.3
 * @deprecated 0.3.3
 * @internal function removed in 0.4
 * @link http://simplepie.org
 */
function hybrid_lifestream( $deprecated = '' ) {
	hybrid_function_removed( 'hybrid_lifestream' );
}

/**
 * Adds admin CSS
 *
 * @since 0.2
 * @deprecated 0.3.2
 * @internal function removed in 0.4
 */
function hybrid_admin_enqueue_style() {
	hybrid_function_removed( 'hybrid_admin_enqueue_style' );
}

/**
 * Dynamic page ID
 *
 * @since 1.0
 * @deprecated 0.2
 * @internal function removed in 0.4
 */
function hybrid_page_id() {
	hybrid_function_removed( 'hybrid_page_id' );
}

/**
 * Dynamic page class
 *
 * @since 0.1
 * @deprecated 0.2
 * @internal function removed in 0.4
 */
function hybrid_page_class() {
	hybrid_function_removed( 'hybrid_page_class' );
}

/**
 * Returns all users
 * Needed with the Members page template
 *
 * @since 0.4
 * @deprecated 0.5
 * @internal Removed in 0.5 because this code was never used
 * @return array
 */
function hybrid_get_users( $deprecated = '' ) {
	hybrid_function_removed( 'hybrid_get_users' );
}

/**
 * Display footnotes at the bottom of posts or pages
 * Collects data from custom field key Footnote
 * Only show footnotes on single posts and pages
 *
 * @since 0.3
 * @deprecated 0.5
 * @internal Removed in 0.5 because this was never used
 */
function hybrid_footnote() {
	hybrid_function_removed( 'hybrid_footnote' );
}

// Add footnotes after single posts and pages
// Removed in 0.5
// @deprecated 0.5
// add_action( 'hybrid_after_page', 'hybrid_footnote' );
// add_action( 'hybrid_after_single', 'hybrid_footnote' );

/**
 * Shows related posts by plugin
 * Only show if related posts plugin is active
 *
 * @since 0.2.2
 * @deprecated 0.5
 * @internal Removed in 0.5 because this was never used
 */
function hybrid_related_posts() {
	hybrid_function_removed( 'hybrid_related_posts' );
}

/**
 * Ability to design custom sidebars with/without widgets
 * Changed from action to filter in 0.2.2
 * Only useful if adding completely custom sidebars/widget areas
 * One could simply create a custom function and hook it w/o using this function
 *
 * @since 0.2
 * @deprecated 0.5
 * @internal Removed in 0.5 b/c this was never used
 */
function hybrid_insert() {
	hybrid_function_removed( 'hybrid_insert' );
}

/**
 * Message to display for removed functions
 *
 * @since 0.5
 */
function hybrid_function_removed( $func = '' ) {
	if( $func )
		$func = '&lt;code>' . $func . '&lt;/code> &mdash; ';
	die( $func . __('This function has been removed or replaced by another function.','hybrid') );
}

?>