<?php
/**
 * Handles widgets and widget areas
 *
 * WP widgets must be unregistered
 * Hybrid widgets must be registered in their place
 * All widget areas are loaded and registered with WP
 *
 * Use register_sidebar() to create custom widget areas
 * @link http://codex.wordpress.org/WordPress_Widgets_Api/register_sidebar
 *
 * @package Hybrid
 * @subpackage Widgets
 */

// Calls function to unregister WP widgets
	add_action( 'widgets_init', 'hybrid_unregister_widgets' );

// Calls function to remove widget areas
	add_filter( 'sidebars_widgets', 'remove_sidebars' );

/*
* Load each widget file
*/
	require_once( HYBRID_WIDGETS . '/archives.php' );
	require_once( HYBRID_WIDGETS . '/authors.php' );
	require_once( HYBRID_WIDGETS . '/bookmarks.php' );
	require_once( HYBRID_WIDGETS . '/calendar.php' );
	require_once( HYBRID_WIDGETS . '/categories.php' );
	require_once( HYBRID_WIDGETS . '/pages.php' );
	require_once( HYBRID_WIDGETS . '/search.php' );
	require_once( HYBRID_WIDGETS . '/tags.php' );

/*
* Register each widget
*/
	widget_hybrid_archives_register();
	widget_hybrid_authors_register();
	widget_hybrid_bookmarks_register();
	widget_hybrid_categories_register();
	widget_hybrid_calendar_register();
	widget_hybrid_pages_register();
	widget_hybrid_search_register();
	widget_hybrid_tags_register();

/*
* Register major widget areas
*/
register_sidebar( array( 'name' => __('Primary', 'hybrid'), 'id' => 'primary', 'before_widget' => '<div id="%1$s" class="widget %2$s widget-%2$s"><div class="widget-inside">', 'after_widget' => '</div></div>', 'before_title' => '<h3 class="widget-title">', 'after_title' => '</h3>' ) );
register_sidebar( array( 'name' => __('Secondary', 'hybrid'), 'id' => 'secondary', 'before_widget' => '<div id="%1$s" class="widget %2$s widget-%2$s"><div class="widget-inside">', 'after_widget' => '</div></div>', 'before_title' => '<h3 class="widget-title">', 'after_title' => '</h3>' ) );
register_sidebar( array( 'name' => __('Subsidiary', 'hybrid'), 'id' => 'subsidiary', 'before_widget' => '<div id="%1$s" class="widget %2$s widget-%2$s"><div class="widget-inside">', 'after_widget' => '</div></div>', 'before_title' => '<h3 class="widget-title">', 'after_title' => '</h3>' ) );

/*
* Register utility widget areas
*/
register_sidebar( array( 'name' => __('Utility: Before Content', 'hybrid'), 'id' => 'utilitybeforecontent', 'before_widget' => '<div id="%1$s" class="widget %2$s widget-%2$s"><div class="widget-inside">', 'after_widget' => '</div></div>', 'before_title' => '<h3 class="widget-title">', 'after_title' => '</h3>' ) );
register_sidebar( array( 'name' => __('Utility: After Content', 'hybrid'), 'id' => 'utilityaftercontent', 'before_widget' => '<div id="%1$s" class="widget %2$s widget-%2$s"><div class="widget-inside">', 'after_widget' => '</div></div>', 'before_title' => '<h3 class="widget-title">', 'after_title' => '</h3>' ) );
register_sidebar( array( 'name' => __('Utility: After Single', 'hybrid'), 'id' => 'utilityaftersingle', 'before_widget' => '<div id="%1$s" class="widget %2$s widget-%2$s"><div class="widget-inside">', 'after_widget' => '</div></div>', 'before_title' => '<h3 class="widget-title">', 'after_title' => '</h3>' ) );
register_sidebar( array( 'name' => __('Utility: After Page', 'hybrid'), 'id' => 'utilityafterpage', 'before_widget' => '<div id="%1$s" class="widget %2$s widget-%2$s"><div class="widget-inside">', 'after_widget' => '</div></div>', 'before_title' => '<h3 class="widget-title">', 'after_title' => '</h3>' ) );
register_sidebar( array( 'name' => __('Utility: Widgets Template', 'hybrid'), 'id' => 'utilitywidgetstemplate', 'before_widget' => '<div id="%1$s" class="widget %2$s widget-%2$s"><div class="widget-inside">', 'after_widget' => '</div></div>', 'before_title' => '<h3 class="widget-title">', 'after_title' => '</h3>' ) );
register_sidebar( array( 'name' => __('Utility: 404', 'hybrid'), 'id' => 'utility404', 'before_widget' => '<div id="%1$s" class="widget %2$s widget-%2$s"><div class="widget-inside">', 'after_widget' => '</div></div>', 'before_title' => '<h3 class="widget-title">', 'after_title' => '</h3>' ) );

/**
 * Unregister default WordPress widgets we don't need
 * The theme adds its own versions of these widgets
 * @uses unregister_sidebar_widget() Removes individual widgets
 * @link http://codex.wordpress.org/WordPress_Widgets_Api/unregister_sidebar_widget
 *
 * @since 0.3.2
 */
function hybrid_unregister_widgets() {
	unregister_sidebar_widget( 'archives' );
	unregister_sidebar_widget( 'calendar' );
	unregister_sidebar_widget( 'categories-1' );
	unregister_sidebar_widget( 'links' );
	unregister_sidebar_widget( 'pages' );
	unregister_sidebar_widget( 'recent-posts' );
	unregister_sidebar_widget( 'search' );
	unregister_sidebar_widget( 'tag_cloud' );
}

/**
 * Loads the Primary widget area
 * Users can overwrite 'aside-primary.php' in child themes
 * @uses locate_template() Checks for template in child and parent theme
 *
 * @since 0.2.2
 */
function hybrid_get_primary() {

	$templates = array( 'aside-primary.php' );

	locate_template( $templates, true );
}

/**
 * Loads the Secondary widget area
 * Users can overwrite 'aside-secondary.php' in child themes
 * @uses locate_template() Checks for template in child and parent theme
 *
 * @since 0.2.2
 */
function hybrid_get_secondary() {

	$templates = array( 'aside-secondary.php' );

	locate_template( $templates, true );
}

/**
 * Loads the Subsidiary widget area
 * Users can overwrite 'aside-subsidiary.php' in child themes
 * @uses locate_template() Checks for template in child and parent theme
 *
 * @since 0.3.1
 */
function hybrid_get_subsidiary() {

	$templates = array( 'aside-subsidiary.php' );

	locate_template( $templates, true );
}

/**
 * Loads the Utility: Before Content widget area
 * Users can overwrite 'utility-before-content.php' in child themes
 * @uses locate_template() Checks for template in child and parent theme
 *
 * @since 0.4
 */
function hybrid_get_utility_before_content() {

	$templates = array( 'utility-before-content.php' );

	locate_template( $templates, true );
}

/**
 * Loads the Utility: After Content widget area
 * Users can overwrite 'utility-after-content.php' in child themes
 * @uses locate_template() Checks for template in child and parent theme
 *
 * @since 0.4
 */
function hybrid_get_utility_after_content() {

	$templates = array( 'utility-after-content.php' );

	locate_template( $templates, true );
}

/**
 * Loads the Utility: After Single widget area
 * Users can overwrite 'utility-after-single.php' in child themes
 * @uses locate_template() Checks for template in child and parent theme
 *
 * @since 0.4
 */
function hybrid_get_utility_after_single() {

	$templates = array( 'utility-after-single.php' );

	locate_template( $templates, true );
}

/**
 * Loads the Utility: After Page widget area
 * Users can overwrite 'utility-after-page.php' in child themes
 * @uses locate_template() Checks for template in child and parent theme
 *
 * @since 0.4
 */
function hybrid_get_utility_after_page() {

	$templates = array( 'utility-after-page.php' );

	locate_template( $templates, true );
}

/**
 * Loads the Utility: 404 widget area
 * Not currently being used
 * Widget area being loaded directoy in '404.php'
 * @uses locate_template() Checks for template in child and parent theme
 *
 * @since 0.4
 */
function hybrid_get_utility_404() {

	$templates = array( 'utility-404.php' );

	locate_template( $templates, true );
}

/**
 * Check for widgets in widget-ready areas
 * Allows user to completely collapse widget-ready areas by not
 * adding widgets to particular widget areas
 *
 * Checks widget areas by name and/or ID
 * Using WP functionality from /wp-includes/widgets.php
 * @uses $wp_registered_sidebars Gets all registered widget areas
 *
 * Major props to Chaos Kaizer and Ian Stewart
 * @link http://wordpress.org/support/topic/190184#post-808787
 * @link http://blog.kaizeku.com
 * @link http://themeshaper.com/collapsing-wordpress-widget-ready-areas-sidebars
 *
 * @since 0.2
 * @param string|int $index name|ID of widget area
 * @return bool
 */
function is_sidebar_active( $index = 1 ) {
	global $wp_registered_sidebars;

	if ( is_int( $index ) ) :
		$index = "sidebar-$index";
	else :
		$index = sanitize_title( $index );
		foreach ( (array) $wp_registered_sidebars as $key => $value ) :
			if ( sanitize_title( $value['name'] ) == $index ) :
				$index = $key;
				break;
			endif;
		endforeach;
	endif;

	$sidebars_widgets = wp_get_sidebars_widgets();

	if ( empty( $wp_registered_sidebars[$index] ) || !array_key_exists( $index, $sidebars_widgets ) || !is_array( $sidebars_widgets[$index] ) || empty( $sidebars_widgets[$index] ) )
		return false;
	else
		return true;
}

/**
 * Removes all widget areas on the No Widgets page template
 * @uses sidebars_widgets Filter to remove all widget areas
 *
 * We're only going to run it on the No Widgets template
 * Users that need additional templates without widgets should 
 * create a simliar function in their child theme.
 *
 * We're retaining the 'sidebar' terminology until such time that
 * the WordPress community decides on a better term.
 *
 * @since 0.5
 */
function remove_sidebars( $sidebars_widgets ) {
	if ( is_page_template( 'no-widgets.php' ) )
		$sidebars_widgets = array( false );
	return $sidebars_widgets;
}

?>