<?php
/**
 * Tags Widget
 *
 * Replaces the default WordPress Tag Cloud widget
 * @link http://themehybrid.com/themes/hybrid/widgets
 *
 * @package Hybrid
 * @subpackage Widgets
 */

/**
 * Output of the tags widget
 * Each setting is an argument for wp_tag_cloud()
 * @link http://codex.wordpress.org/Template_Tags/wp_tag_cloud
 *
 * @since 0.3.3
 */
function widget_hybrid_tags( $args, $widget_args = 1 ) {

	extract( $args, EXTR_SKIP );

	if ( is_numeric( $widget_args ) )
		$widget_args = array( 'number' => $widget_args );

	$widget_args = wp_parse_args( $widget_args, array( 'number' => -1 ) );

	extract( $widget_args, EXTR_SKIP );

	$options = get_option( 'widget_hybrid_tags' );

	if ( !isset( $options[$number] ) )
		return;

	$title = apply_filters( 'widget_title', $options[$number]['title'] );
	$format = $options[$number]['format'];
	$order = $options[$number]['order'];
	$orderby = $options[$number]['orderby'];
	$unit = $options[$number]['unit'];
	$largest = (int)$options[$number]['largest'];
	$smallest = (int)$options[$number]['smallest'];
	$tag_number = (int)$options[$number]['tag_number'];
	$exclude = $options[$number]['exclude'];
	$include = $options[$number]['include'];

	if ( !$largest )
		$largest = 22;
	if ( !$smallest )
		$smallest = 8;

	$tags = array(
		'smallest' => $smallest,
		'largest' => $largest,
		'unit' => $unit,
		'number' => $tag_number,
		'format' => $format,
		'orderby' => $orderby,
		'order' => $order,
		'exclude' => $exclude,
		'include' => $include,
	);

	echo $before_widget;

	if ( $title )
		echo $before_title . $title . $after_title;

	if ( $format == 'flat' ) :
		echo '<p class="tag-cloud">';
		wp_tag_cloud( $tags );
		echo '</p>';
	else :
		wp_tag_cloud( $tags );
	endif;

	echo $after_widget;
}

/**
 * Widget controls for the tags widget
 * Options are chosen from user input from the widget panel
 *
 * @since 0.3.3
 */
function widget_hybrid_tags_control( $widget_args ) {

	global $wp_registered_widgets;

	static $updated = false;

	if ( is_numeric( $widget_args ) )
		$widget_args = array( 'number' => $widget_args );

	$widget_args = wp_parse_args( $widget_args, array( 'number' => -1 ) );

	extract( $widget_args, EXTR_SKIP );

	$options = get_option( 'widget_hybrid_tags' );

	if ( !is_array( $options ) )
		$options = array();

	if ( !$updated && !empty( $_POST['sidebar'] ) ) :

		$sidebar = (string)$_POST['sidebar'];

		$sidebars_widgets = wp_get_sidebars_widgets();

		if ( isset( $sidebars_widgets[$sidebar] ) )
			$this_sidebar =& $sidebars_widgets[$sidebar];
		else
			$this_sidebar = array();

		foreach ( $this_sidebar as $_widget_id ) :

			if ( 'widget_hybrid_tags' == $wp_registered_widgets[$_widget_id]['callback'] && isset( $wp_registered_widgets[$_widget_id]['params'][0]['number'] ) ) :

				$widget_number = $wp_registered_widgets[$_widget_id]['params'][0]['number'];

				unset( $options[$widget_number] );

			endif;

		endforeach;

		foreach ( (array)$_POST['widget-hybrid-tags'] as $widget_number => $widget_hybrid_tags ) :

			$title = strip_tags( stripslashes( $widget_hybrid_tags['title'] ) );

			$tag_number = strip_tags( stripslashes( $widget_hybrid_tags['tag_number'] ) );

			$format = strip_tags( stripslashes( $widget_hybrid_tags['format'] ) );

			$smallest = strip_tags( stripslashes( $widget_hybrid_tags['smallest'] ) );

			$largest = strip_tags( stripslashes( $widget_hybrid_tags['largest'] ) );

			$unit = strip_tags( stripslashes( $widget_hybrid_tags['unit'] ) );

			$order = strip_tags( stripslashes( $widget_hybrid_tags['order'] ) );

			$orderby = strip_tags( stripslashes( $widget_hybrid_tags['orderby'] ) );

			$exclude = strip_tags( stripslashes( $widget_hybrid_tags['exclude'] ) );

			$include = strip_tags( stripslashes( $widget_hybrid_tags['include'] ) );

			$options[$widget_number] = compact( 'title', 'smallest', 'largest', 'unit', 'tag_number', 'format', 'orderby', 'order', 'exclude', 'include' );

		endforeach;

		update_option( 'widget_hybrid_tags', $options );

		$updated = true;

	endif;

	if ( $number == -1 ) :
		$title = '';
		$smallest = '';
		$largest = '';
		$unit = '';
		$tag_number = '';
		$format = '';
		$orderby = '';
		$order = '';
		$exclude = '';
		$include = '';
		$number = '%i%';
	else :
		$title = attribute_escape( $options[$number]['title'] );
		$smallest = attribute_escape( $options[$number]['smallest'] );
		$largest = attribute_escape( $options[$number]['largest'] );
		$unit = attribute_escape( $options[$number]['unit'] );
		$tag_number = attribute_escape( $options[$number]['tag_number'] );
		$format = attribute_escape( $options[$number]['format'] );
		$orderby = attribute_escape( $options[$number]['orderby'] );
		$order = attribute_escape( $options[$number]['order'] );
		$exclude = attribute_escape( $options[$number]['exclude'] );
		$include = attribute_escape( $options[$number]['include'] );
	endif;

?>

	<div style="float:left;width:48%;">
	<p>
		<label for="hybrid-tags-title-<?php echo $number; ?>">
			<?php _e('Title:','hybrid'); ?>
		</label>
		<input id="hybrid-tags-title-<?php echo $number; ?>" name="widget-hybrid-tags[<?php echo $number; ?>][title]" type="text" value="<?php echo $title; ?>" style="width:100%;" />
	</p>
	<p>
		<label for="hybrid-tags-format-<?php echo $number; ?>">
			<?php _e('Format:','hybrid'); ?> <code>format</code>
		</label>

		<select id="hybrid-tags-format-<?php echo $number; ?>" name="widget-hybrid-tags[<?php echo $number; ?>][format]" class="widefat" style="width:100%;">
			<option <?php if ( 'flat' == $format ) echo 'selected="selected"'; ?>>flat</option>
			<option <?php if ( 'list' == $format ) echo 'selected="selected"'; ?>>list</option>
		</select>
	</p>
	<p>
		<label for="hybrid-tags-order-<?php echo $number; ?>">
			<?php _e('Order:','hybrid'); ?> <code>order</code>
		</label>

		<select id="hybrid-tags-order-<?php echo $number; ?>" name="widget-hybrid-tags[<?php echo $number; ?>][order]" class="widefat" style="width:100%;">
			<option <?php if ( 'ASC' == $order ) echo 'selected="selected"'; ?>>ASC</option>
			<option <?php if ( 'DESC' == $order ) echo 'selected="selected"'; ?>>DESC</option>
			<option <?php if ( 'RAND' == $order ) echo 'selected="selected"'; ?>>RAND</option>
		</select>
	</p>
	<p>
		<label for="hybrid-tags-orderby-<?php echo $number; ?>">
			<?php _e('Order By:','hybrid'); ?> <code>orderby</code>
		</label>

		<select id="hybrid-tags-orderby-<?php echo $number; ?>" name="widget-hybrid-tags[<?php echo $number; ?>][orderby]" class="widefat" style="width:100%;">
			<option <?php if ( 'name' == $orderby ) echo 'selected="selected"'; ?>>name</option>
			<option <?php if ( 'count' == $orderby ) echo 'selected="selected"'; ?>>count</option>
		</select>
	</p>
	<p>
		<label for="hybrid-tags-tag_number-<?php echo $number; ?>">
			<?php _e('Number:','hybrid'); ?> <code>number</code>
		</label>
		<input id="hybrid-tags-tag_number-<?php echo $number; ?>" name="widget-hybrid-tags[<?php echo $number; ?>][tag_number]" type="text" value="<?php echo $tag_number; ?>" style="width:100%;" />
	</p>
	</div>
	<div style="float:right;width:48%;">
	<p>
		<label for="hybrid-tags-largest-<?php echo $number; ?>">
			<?php _e('Largest:','hybrid'); ?> <code>largest</code>
		</label>
		<input id="hybrid-tags-largest-<?php echo $number; ?>" name="widget-hybrid-tags[<?php echo $number; ?>][largest]" type="text" value="<?php echo $largest; ?>" style="width:100%;" />
	</p>
	<p>
		<label for="hybrid-tags-smallest-<?php echo $number; ?>">
			<?php _e('Smallest:','hybrid'); ?> <code>smallest</code>
		</label>
		<input id="hybrid-tags-smallest-<?php echo $number; ?>" name="widget-hybrid-tags[<?php echo $number; ?>][smallest]" type="text" value="<?php echo $smallest; ?>" style="width:100%;" />
	</p>
	<p>
		<label for="hybrid-tags-unit-<?php echo $number; ?>">
			<?php _e('Unit:','hybrid'); ?> <code>unit</code>
		</label>

		<select id="hybrid-tags-unit-<?php echo $number; ?>" name="widget-hybrid-tags[<?php echo $number; ?>][unit]" class="widefat" style="width:100%;">
			<option <?php if ( 'pt' == $unit ) echo 'selected="selected"'; ?>>pt</option>
			<option <?php if ( 'px' == $unit ) echo 'selected="selected"'; ?>>px</option>
			<option <?php if ( 'em' == $unit ) echo 'selected="selected"'; ?>>em</option>
			<option <?php if ( '%' == $unit ) echo 'selected="selected"'; ?>>%</option>
		</select>
	</p>
	<p>
		<label for="hybrid-tags-exclude-<?php echo $number; ?>">
			<?php _e('Exclude:','hybrid'); ?> <code>exclude</code>
		</label>
		<input id="hybrid-tags-exclude-<?php echo $number; ?>" name="widget-hybrid-tags[<?php echo $number; ?>][exclude]" type="text" value="<?php echo $exclude; ?>" style="width:100%;" />
	</p>
	<p>
		<label for="hybrid-tags-include-<?php echo $number; ?>">
			<?php _e('Include:','hybrid'); ?> <code>include</code>
		</label>
		<input id="hybrid-tags-include-<?php echo $number; ?>" name="widget-hybrid-tags[<?php echo $number; ?>][include]" type="text" value="<?php echo $include; ?>" style="width:100%;" />
	</p>
	</div>

	<p style="clear:both;">
		<input type="hidden" id="hybrid-tags-submit-<?php echo $number; ?>" name="hybrid-tags-submit-<?php echo $number; ?>" value="1" />
	</p>
<?php
}

/**
 * Register the tags widget
 * Register the tags widget controls
 *
 * @since 0.3.3
 */
function widget_hybrid_tags_register() {

	if ( !$options = get_option( 'widget_hybrid_tags' ) )
		$options = array();

	$widget_ops = array(
		'classname' => 'tags',
		'description' => __('An advanced widget that gives you total control over the output of your tags.','hybrid'),
	);

	$control_ops = array(
		'width' => 700,
		'height' => 350,
		'id_base' => 'hybrid-tags',
	);

	$name = __('Tags','hybrid');

	$id = false;

	foreach ( array_keys( $options ) as $o ) :

		if ( !isset( $options[$o]['title'] ) )
			continue;

		$id = 'hybrid-tags-' . $o;

		wp_register_sidebar_widget( $id, $name, 'widget_hybrid_tags', $widget_ops, array( 'number' => $o ) );

		wp_register_widget_control( $id, $name, 'widget_hybrid_tags_control', $control_ops, array( 'number' => $o ) );

	endforeach;

	if ( !$id ) :

		wp_register_sidebar_widget( 'hybrid-tags-1', $name, 'widget_hybrid_tags', $widget_ops, array( 'number' => -1 ) );

		wp_register_widget_control( 'hybrid-tags-1', $name, 'widget_hybrid_tags_control', $control_ops, array( 'number' => -1 ) );

	endif;

}

?>