<?php
/**
 * Template Name: Logged In
 *
 * A template that only allows logged in users to view the content.
 * @link http://themehybrid.com/themes/hybrid/page-templates/logged-in
 * Uses the is_user_logged_in() function to check.
 * @link http://codex.wordpress.org/Function_Reference/is_user_logged_in
 *
 * @package Hybrid
 * @subpackage Template
 */

get_header(); ?>

	<div class="hfeed content">

		<?php hybrid_before_content(); // Before content hook ?>

		<?php if ( have_posts() && is_user_logged_in() ) : while ( have_posts() ) : the_post(); ?>

			<div id="post-<?php the_ID(); ?>" class="<?php hybrid_entry_class(); ?>">

				<?php hybrid_before_entry(); // Before entry hook ?>

				<div class="entry-content entry">
					<?php the_content(); ?>
					<?php wp_link_pages( array( 'before' => '<p class="pages">' . __('Pages:', 'hybrid'), 'after' => '</p>' ) ); ?>
				</div>

				<?php hybrid_after_entry(); // After entry hook ?>

			</div>

			<?php endwhile; ?>

			<?php hybrid_after_page(); // After page hook ?>

			<?php comments_template( '', true ); ?>

		<?php elseif ( have_posts() && !is_user_logged_in() ) : // If user is not logged in ?>

			<div id="post-0" class="<?php hybrid_entry_class(); ?>">

				<?php hybrid_before_entry(); // Before entry hook ?>

				<div class="entry-content entry">

					<p class="alert">
						<?php printf( __('You must be <a href="%1$s" title="Log in">logged in</a> to view the content of this page.', 'hybrid'), wp_login_url( get_permalink() ) ); ?>

						<?php if ( get_option( 'users_can_register' ) ) : ?>
							<?php printf( __('If you\'re not currently a member, please take a moment to <a href="%1$s" title="Register">register</a>.', 'hybrid'), get_option( 'siteurl' ) . '/wp-register.php' ); ?>
						<?php endif; ?>
					</p>

				</div>

				<?php hybrid_after_entry(); // After entry hook ?>

			</div>

			<?php hybrid_after_page(); // After page hook ?>

		<?php else: ?>

			<p class="no-data"><?php _e('Sorry, no page matched your criteria.', 'hybrid'); ?></p>

		<?php endif; ?>

		<?php hybrid_after_content(); // After content hook ?>

	</div>

<?php get_footer(); ?>