<?php
/**
 * Template Name: Profile
 *
 * Allow users to update their profiles.
 * Note that this template is under heavy development and may change drastically in the future.
 * @link http://themehybrid.com/themes/hybrid/page-templates/profile
 *
 * As with any system where you allow open user registration, there are security risks.
 * WordPress handles this the best it can.
 * You should do everything you can to keep your site secure, 
 * such as, but not limited to, making regular DB backups.
 *
 * @package Hybrid
 * @subpackage Template
 */

// Get user info
	global $current_user, $wp_roles;
	get_currentuserinfo();

// Load the registration file
	require_once( ABSPATH . WPINC . '/registration.php' );

if ( 'POST' == $_SERVER['REQUEST_METHOD'] && !empty( $_POST['action'] ) && $_POST['action'] == 'update-user' ) :

	/*
	* Update user password
	*/
	if ( !empty($_POST['pass1'] ) && !empty( $_POST['pass2'] ) ) :
		if ( $_POST['pass1'] == $_POST['pass2'] ) :
			wp_update_user( array( 'ID' => $current_user->id, 'user_pass' => $_POST['pass1'] ) );
		else :
			$error = __('The passwords you entered do not match.  Your password was not updated.', 'hybrid');
		endif;
	endif;

	/*
	* Update user information
	*/
	if ( !empty( $_POST['url'] ) )
		update_usermeta( $current_user->id, 'user_url', $_POST['url'] );
	if ( !empty( $_POST['email'] ) )
		update_usermeta( $current_user->id, 'user_email', $_POST['email'] );
	if ( !empty( $_POST['first-name'] ) )
		update_usermeta( $current_user->id, 'first_name', $_POST['first-name'] );
	if ( !empty( $_POST['last-name'] ) )
		update_usermeta($current_user->id, 'last_name', $_POST['last-name'] );
	if ( !empty( $_POST['description'] ) )
		update_usermeta( $current_user->id, 'description', $_POST['description'] );

	/*
	* Redirect so the page will show updated info
	*/
	if ( !$error ) :
		wp_redirect( $_SERVER['REQUEST_URI'] );
		exit;
	endif;

endif;

get_header(); ?>

	<div class="hfeed content">

		<?php hybrid_before_content(); // Before content hook ?>

		<?php if ( have_posts() ) : while ( have_posts() ) : the_post(); ?>

			<div id="post-<?php the_ID(); ?>" class="<?php hybrid_entry_class(); ?>">

				<?php hybrid_before_entry(); // Before entry hook ?>

				<div class="entry-content entry">

					<?php the_content(); ?>

					<?php if ( !is_user_logged_in() ) : ?>

						<p class="warning">
							<?php _e('You must be logged in to edit your profile.', 'hybrid'); ?>
						</p>

					<?php else : ?>

						<?php if ( $error ) echo '<p class="error">' . $error . '</p>'; ?>

						<form method="post" id="adduser" action="http://<?php echo $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI']; ?>">
						<p>
							<label for="first-name"><?php _e('First Name', 'hybrid'); ?></label>
							<input class="text-input" name="first-name" type="text" id="first-name" value="<?php echo wp_specialchars( $current_user->user_firstname, 1 ); ?>" />
						</p>
						<p>
							<label for="last-name"><?php _e('Last Name', 'hybrid'); ?></label>
							<input class="text-input" name="last-name" type="text" id="last-name" value="<?php echo wp_specialchars( $current_user->user_lastname, 1 ); ?>" />
						</p>
						<p>
							<label for="email"><?php _e('E-mail *', 'hybrid'); ?></label>
							<input class="text-input" name="email" type="text" id="email" value="<?php echo wp_specialchars( $current_user->user_email, 1 ); ?>" />
						</p>
						<p>
							<label for="url"><?php _e('Website', 'hybrid'); ?></label>
							<input class="text-input" name="url" type="text" id="url" value="<?php echo wp_specialchars( $current_user->user_url, 1 ); ?>" />
						</p>
						<p>
							<label for="pass1"><?php _e('Password *', 'hybrid'); ?> </label>
							<input class="text-input" name="pass1" type="password" id="pass1" />
						</p>
						<p>
							<label for="pass2"><?php _e('Repeat Password *', 'hybrid'); ?></label>
							<input class="text-input" name="pass2" type="password" id="pass2" />
						</p>
						<p>
							<label for="description"><?php _e('Biographical Information', 'hybrid') ?></label>
							<textarea name="description" id="description" rows="3" cols="50"><?php echo wp_specialchars( $current_user->description, 1 ); ?></textarea>
						</p>
						<p>
							<?php echo $referer; ?>
							<input name="updateuser" type="submit" id="updateuser" class="submit button" value="<?php _e('Update', 'hybrid'); ?>" />
							<?php wp_nonce_field( 'update-user' ) ?>
							<input name="action" type="hidden" id="action" value="update-user" />
						</p>

						</form>

					<?php endif; ?>

					<?php wp_link_pages( array( 'before' => '<p class="pages">' . __('Pages:', 'hybrid'), 'after' => '</p>' ) ); ?>

				</div>

				<?php hybrid_after_entry(); // After entry hook ?>

			</div>

			<?php endwhile; ?>

			<?php hybrid_after_page(); // After page hook ?>

			<?php comments_template( '', true ); ?>

		<?php else: ?>

			<p class="no-data"><?php _e('Sorry, no page matched your criteria.', 'hybrid'); ?></p>

		<?php endif; ?>

		<?php hybrid_after_content(); // After content hook ?>

	</div>

<?php get_footer(); ?>