<?php
/**
 * Template Name: Sitemap
 *
 * Creates an XHTML sitemap for your site, listing everything.
 * This template lists your feeds, pages, archives, and posts.
 * @link http://themehybrid.com/themes/hybrid/page-templates/sitemap
 *
 * @package Hybrid
 * @subpackage Template
 */

get_header(); ?>

	<div class="hfeed content">

		<?php hybrid_before_content(); // Before content hook ?>

		<?php if ( have_posts() ) : while ( have_posts() ) : the_post(); ?>

			<div id="post-<?php the_ID(); ?>" class="<?php hybrid_entry_class(); ?>">

				<?php hybrid_before_entry(); // Before entry hook ?>

				<div class="entry-content entry">

					<?php the_content(); ?>

					<h2><?php _e('Feeds', 'hybrid'); ?></h2>

					<ul class="xoxo feeds">
						<li><a href="<?php bloginfo( 'rdf_url' ); ?>" title="<?php _e('RDF/RSS 1.0 feed', 'hybrid'); ?>"><?php _e('<acronym title="Resource Description Framework">RDF</acronym> <acronym title="Really Simple Syndication">RSS</acronym> 1.0 feed', 'hybrid'); ?></a></li>
						<li><a href="<?php bloginfo( 'rss_url' ); ?>" title="<?php _e('RSS 0.92 feed', 'hybrid'); ?>"><?php _e('<acronym title="Really Simple Syndication">RSS</acronym> 0.92 feed', 'hybrid'); ?></a></li>
						<li><a href="<?php bloginfo( 'rss2_url' ); ?>" title="<?php _e('RSS 2.0 feed', 'hybrid'); ?>"><?php _e('<acronym title="Really Simple Syndication">RSS</acronym> 2.0 feed', 'hybrid'); ?></a></li>
						<li><a href="<?php bloginfo( 'atom_url' ); ?>" title="<?php _e('Atom feed', 'hybrid'); ?>"><?php _e('Atom feed', 'hybrid'); ?></a></li>
						<li><a href="<?php bloginfo( 'comments_rss2_url' ); ?>" title="<?php _e('Comments RSS 2.0 feed', 'hybrid'); ?>"><?php _e('Comments <acronym title="Really Simple Syndication">RSS</acronym> 2.0 feed', 'hybrid'); ?></a></li>
					</ul>

					<h2><?php _e('Pages', 'hybrid'); ?></h2>

					<ul class="xoxo pages">
						<li><a href="<?php bloginfo( 'siteurl' ); ?>" title="<?php bloginfo( 'name' ); ?>"><?php _e('Home','hybrid'); ?></a></li>
						<?php wp_list_pages( 'title_li=' ); ?>
					</ul>

					<h2><?php _e('Category Archives', 'hybrid'); ?></h2>

					<ul class="xoxo category-archives">
						<?php wp_list_categories( 'feed=RSS&show_count=1&use_desc_for_title=0&title_li=' ); ?>
					</ul>

					<h2><?php _e('Author Archives', 'hybrid'); ?></h2>

					<ul class="xoxo author-archives">
						<?php wp_list_authors( 'exclude_admin=0&show_fullname=1&feed=RSS&optioncount=1&title_li=' ); ?>
					</ul>

					<h2><?php _e('Yearly Archives', 'hybrid'); ?></h2>

					<ul class="xoxo yearly-archives">
						<?php wp_get_archives( 'type=yearly&show_post_count=1' ); ?>
					</ul>

					<h2><?php _e('Monthly Archives', 'hybrid'); ?></h2>

					<ul class="xoxo monthly-archives">
						<?php wp_get_archives( 'type=monthly&show_post_count=1' ); ?>
					</ul>

					<h2><?php _e('Weekly Archives', 'hybrid'); ?></h2>

					<ul class="xoxo weekly-archives">
						<?php wp_get_archives( 'type=weekly&show_post_count=1' ); ?>
					</ul>

					<h2><?php _e('Daily Archives', 'hybrid'); ?></h2>

					<ul class="xoxo daily-archives">
						<?php wp_get_archives( 'type=daily&show_post_count=1' ); ?>
					</ul>

					<h2><?php _e('Tag Archives', 'hybrid'); ?></h2>

					<p class="tag-cloud">
						<?php wp_tag_cloud( 'number=0' ); ?>
					</p>

					<h2><?php _e('Blog Posts', 'hybrid'); ?></h2>

					<ul class="xoxo post-archives">
						<?php wp_get_archives( 'type=postbypost' ); ?>
					</ul>

					<?php wp_link_pages( array( 'before' => '<p class="pages">' . __('Pages:', 'hybrid'), 'after' => '</p>' ) ); ?>

				</div>

				<?php hybrid_after_entry(); // After entry hook ?>

			</div>

			<?php hybrid_after_page(); // After page hook ?>

			<?php comments_template( '', true ); ?>

			<?php endwhile; ?>

		<?php else: ?>

			<p class="no-data"><?php _e('Sorry, no page matched your criteria.', 'hybrid'); ?></p>

		<?php endif; ?>

		<?php hybrid_after_content(); // After content hook ?>

	</div>

<?php get_footer(); ?>